Project Co-ordinator - Graduate or equivalent | Job Application | - Apply | Office Angels
Description: , Project Co-ordinator - Graduate or equivalent, Office and Secretarial
Keywords: , Office and Secretarial, Permanent, , Day, England

[City],[Region],[Country],[Province],[PostalCode]
[City],[Province]

- [enter text]
- Adecco World

- Find a job
- Help & advice
- Working with you

bckTop,ttlBdy,brdCrmb,shrBtn_Bottom,shrBtn,leftNav

## Application for: Project Co-ordinator - Graduate or equivalent ## Personal details First name* Last name* Address line 1* Address line 2* City Province Country Post code* Phone* Email* Confirm email* ## About you Your skills Your education Your ideal new job title Anything else you'd like us to know? ## Your CV and cover letter ### Your documents must be less than 1 MB and in .doc, .docx, .pdf or .rtf formats. Upload your CV* Your cover letter Upload a file or write it here in the form Remember these details More about remembering these details
| In |
## Job details: Project Co-ordinator - Graduate or equivalent Contract type Permanent Location: Map Basingstoke, Hampshire Salary: (Per Annum) : £25,000 - 40,000 Category: Office and Secretarial, Administrator Reference: P998653 Posted: 12 November 2015 Are you an ambitious Graduate (or equivalent) seeking an exciting business role supporting a Project Manager? This could be just for you... Our busy Telecoms client based near central Basingstoke is looking for recruit a Graduate or equivalent on a permanent basis. We are looking for an ambitious, quick learner with the ability to think outside the box and work in a pressured environment supporting the company Project Manager. You will be quick and eager to learn, highly presentable and confident. You will also ideally have three years commercial experience. IF THIS SOUNDS OF INTEREST, PLEASE CALL US ON 01256 464744. Office Angels is acting as an Employment Agency in relation to this vacancy. The Adecco Group UK & Ireland is an Equal Opportunities Employer. ExpandCollapse

Before applying please read and understand the Terms and Conditions (opens in a new window)

- © Office Angels 2013
- Contact us
- Feedback
- Terms & Conditions
- Privacy Policy
- Cookie Policy
- Press office
- Careers at Office Angels

x

## Receive jobs by email matching:

close
close
close
close
close
close
close